@@ -4,14 +4,19 @@
 #' occurs after statistical transformation and will affect the visual appearance
 #' of geoms. The main difference is that it takes a single transformer that is
 #' applied to the x and y axes simultaneously. Any transformers produced by
-#' [ggforce::linear_trans()] that have x and y arguments should work,
-#' but any other transformers produced using [scales::trans_new()] that take x
-#' and y arguments should also work. Axis limits will be adjusted to account for
-#' transformation unless limits are specified with `xlim` or `ylim`. This only
-#' works with geoms where all points are defined with x and y
-#' coordinates (e.g., [ggplot2::geom_point()], [ggplot2::geom_polygon()]). This
-#' does not currently work with geoms where point coordinates are extrapolated
-#' (e.g., [ggplot2::geom_rect()]).
+#' [ggforce::linear_trans()] that have x and y arguments should work, but any
+#' other transformers produced using [scales::trans_new()] that take x and y
+#' arguments should also work. Axis limits will be adjusted to account for
+#' transformation unless limits are specified with `xlim` or `ylim`.
+#'
+#' @details This coordinate system only works with geoms where all points are
+#'   defined with x and y coordinates (e.g., [ggplot2::geom_point()],
+#'   [ggplot2::geom_polygon()]). This does not currently work with geoms where
+#'   point coordinates are extrapolated (e.g., [ggplot2::geom_rect()]).
+#'   Furthermore, when used with ggplot2 3.5.0 and later, some transformation
+#'   edge cases may cause problems with rendering axis lines. This includes not
+#'   currently support "capping" axes. I hope to support all of these geoms,
+#'   edge cases, and features in the future.
 #'
 #' @param trans Transformer for x and y axes.
 #' @importFrom ggplot2 ggproto
@@ -54,56 +59,24 @@ coord_trans_xy <- function(trans = NULL, xlim = NULL, ylim = NULL,
   )
 }
 
-#' @importFrom ggplot2 expansion
-default_expansion <- function(scale, discrete = expansion(add = 0.6),
-                              continuous = expansion(mult = 0.05),
-                              expand = TRUE) {
-  if (!expand) {
-    return(expansion(0, 0))
-  }
-
-  if (!inherits(scale$expand, "waiver")) {
-    scale$expand
-  } else if (scale$is_discrete()) {
-    discrete
-  } else {
-    continuous
-  }
+default_expansion <- function(...) {
+  asNamespace("ggplot2")$default_expansion(...)
 }
 
-expand_range4 <- function(limits, expand) {
-  if (!(is.numeric(expand) && length(expand) %in% c(2, 4))) {
-    cli_abort("{.arg expand} must be a numeric vector with 2 or 4
-              elements")
-  }
-
-  if (all(!is.finite(limits))) {
-    return(c(-Inf, Inf))
-  }
-
-  # If only two expansion constants are given (i.e. the old syntax),
-  # reuse them to generate a four-element expansion vector
-  if (length(expand) == 2) {
-    expand <- c(expand, expand)
-  }
-
-  # Calculate separate range expansion for the lower and
-  # upper range limits, and then combine them into one vector
-  lower <- scales::expand_range(limits, expand[1], expand[2])[1]
-  upper <- scales::expand_range(limits, expand[3], expand[4])[2]
-  c(lower, upper)
+expand_range4 <- function(...) {
+  asNamespace("ggplot2")$expand_range4(...)
 }
 
-dist_euclidean <- function(x, y) {
-  n <- length(x)
-  sqrt((x[-n] - x[-1])^2 + (y[-n] - y[-1])^2)
+dist_euclidean <- function(...) {
+  asNamespace("ggplot2")$dist_euclidean(...)
 }
 
 #' @rdname coord_trans_xy
 #' @format NULL
 #' @usage NULL
 #' @importFrom ggplot2 ggproto CoordCartesian CoordTrans ggproto_parent
-#' @importFrom scales rescale
+#' @importFrom ggplot2 transform_position
+#' @importFrom scales rescale squish_infinite
 #' @export
 CoordTransXY <- ggproto("CoordTransXY", CoordTrans,
   distance = function(self, x, y, panel_params) {
@@ -173,6 +146,7 @@ CoordTransXY <- ggproto("CoordTransXY", CoordTrans,
                                      continuous_range = scale_range_x_sec),
         x.range = out_x$range,
         x.range.coord = range_x_coord,
+        x.full.range = final_scale_limits$x[c(1, 4)],
         x.labels = out_x$labels,
         x.major = rescale(out_x$major_source, 0:1, scale_range_x),
         x.minor = rescale(out_x$minor_source, 0:1, scale_range_x),
@@ -188,6 +162,7 @@ CoordTransXY <- ggproto("CoordTransXY", CoordTrans,
                                      continuous_range = scale_range_y_sec),
         y.range = out_y$range,
         y.range.coord = range_y_coord,
+        y.full.range = final_scale_limits$y[c(1, 4)],
         y.labels = out_y$labels,
         y.major = rescale(out_y$major_source, 0:1, scale_range_y),
         y.minor = rescale(out_y$minor_source, 0:1, scale_range_y),
@@ -202,9 +177,19 @@ CoordTransXY <- ggproto("CoordTransXY", CoordTrans,
   transform = function(self, data, panel_params) {
     new_data <- data
     # transform x and y coordinates
-    if ("x" %in% colnames(data)) {
-      # a bit of a hack for axis tick labels
-      if (all(data$x == -Inf)) {
+    if ("x" %in% colnames(new_data)) {
+      # hacks for axis lines
+      if (all(data$y == panel_params$y.full.range[1])) {
+        new_data$x <- rescale(data$x, 0:1, range(data$x))
+      } else if (all(data$y == panel_params$y.full.range[2])) {
+        new_data$x <- rescale(data$x, 0:1, range(data$x))
+      } else if (all(data$x == panel_params$x.full.range[1])) {
+        new_data$y <- rescale(data$y, 0:1, range(data$y))
+      } else if (all(data$x == panel_params$x.full.range[2])) {
+        new_data$y <- rescale(data$y, 0:1, range(data$y))
+      }
+      # hacks for axis tick labels
+      else if (all(data$x == -Inf)) {
         new_data$y <- rescale(data$y, 0:1, panel_params$y$continuous_range)
       } else if (all(data$x == Inf)) {
         new_data$y <- rescale(data$y, 0:1, panel_params$y.sec$continuous_range)
@@ -219,156 +204,135 @@ CoordTransXY <- ggproto("CoordTransXY", CoordTrans,
       }
     }
     # transform end points for segments
-    if ("xend" %in% colnames(data)) {
-      temp_data <- self$trans$transform(data$xend, data$yend)
+    if ("xend" %in% colnames(new_data)) {
+      temp_data <- self$trans$transform(new_data$xend, new_data$yend)
       new_data$xend <- rescale(temp_data$x, 0:1, panel_params$x.range.coord)
       new_data$yend <- rescale(temp_data$y, 0:1, panel_params$y.range.coord)
     }
     # TODO: transform corners for geom_rect?
-    new_data
+    transform_position(new_data, squish_infinite, squish_infinite)
   }
 )
 
-view_scale_primary <- function(scale, limits = scale$get_limits(),
-                               continuous_range =
-                                 scale$dimension(limits = limits)) {
-  if (!scale$is_discrete()) {
-    # continuous_range can be specified in arbitrary order, but
-    # continuous scales expect the one in ascending order.
-    continuous_scale_sorted <- sort(continuous_range)
-    breaks <- scale$get_breaks(continuous_scale_sorted)
-    minor_breaks <- scale$get_breaks_minor(b = breaks,
-                                           limits = continuous_scale_sorted)
-  } else {
-    breaks <- scale$get_breaks(limits)
-    minor_breaks <- scale$get_breaks_minor(b = breaks, limits = limits)
+view_scale_primary <- function(...) {
+  asNamespace("ggplot2")$view_scale_primary(...)
+}
+
+if (packageVersion("ggplot2") >= "3.5.0") {
+  view_scale_secondary <- function(...) {
+    asNamespace("ggplot2")$view_scale_secondary(...)
   }
-
-  ggproto(NULL, ViewScale,
-    scale = scale,
-    guide = scale$guide,
-    position = scale$position,
-    aesthetics = scale$aesthetics,
-    name = scale$name,
-    scale_is_discrete = scale$is_discrete(),
-    limits = limits,
-    continuous_range = continuous_range,
-    breaks = breaks,
-    minor_breaks = minor_breaks
-  )
-}
-
-scale_flip_position <- function(scale) {
-  scale$position <- switch(scale$position,
-    top = "bottom",
-    bottom = "top",
-    left = "right",
-    right = "left",
-    scale$position
-  )
-  invisible()
-}
-
-view_scale_secondary <- function(scale, limits = scale$get_limits(),
-                                 continuous_range =
-                                   scale$dimension(limits = limits)) {
-  if (is.null(scale$secondary.axis) ||
-      inherits(scale$secondary.axis, "waiver") ||
-      scale$secondary.axis$empty()) {
-    # if there is no second axis, return the primary scale with no guide
-    # this guide can be overridden using guides()
-    primary_scale <- view_scale_primary(scale, limits, continuous_range)
-    scale_flip_position(primary_scale)
-    primary_scale$guide <- ggplot2::guide_none()
-    primary_scale
-  } else {
-    scale$secondary.axis$init(scale)
-    break_info <- scale$secondary.axis$break_info(continuous_range, scale)
-    names(break_info) <- gsub("sec\\.", "", names(break_info))
-
-    # flip position from the original scale by default
-    # this can (should) be overridden in the guide
-    position <- switch(scale$position,
-      top = "bottom",
-      bottom = "top",
-      left = "right",
-      right = "left",
-      scale$position
-    )
-
-    ggproto(NULL, ViewScale,
-      scale = scale,
-      guide = scale$secondary.axis$guide,
-      position = position,
-      break_info = break_info,
-      # as far as scales are concerned, this is a regular scale with
-      # different breaks and labels in a different data space
-      aesthetics = scale$aesthetics,
-      name = scale$sec_name(),
-      make_title = function(self, title) self$scale$make_sec_title(title),
-      limits = limits,
-      continuous_range = continuous_range,
-      dimension = function(self) self$break_info$range,
-      get_limits = function(self) self$break_info$range,
-      get_breaks = function(self) self$break_info$major_source,
-      get_breaks_minor = function(self) self$break_info$minor_source,
-      break_positions = function(self) self$break_info$major,
-      break_positions_minor = function(self) self$break_info$minor,
-      get_labels = function(self, breaks = self$get_breaks()) {
-        self$break_info$labels
-      },
-      rescale = function(x) rescale(x, from = break_info$range, to = c(0, 1))
+} else { # nocov start
+  scale_flip_position <- function(scale) {
+    scale$position <- switch(scale$position,
+                             top = "bottom",
+                             bottom = "top",
+                             left = "right",
+                             right = "left",
+                             scale$position
     )
+    invisible()
   }
-}
-
-
-ViewScale <- ggproto("ViewScale", NULL,
-  # map, rescale, and make_title need a reference
-  # to the original scale
-  scale = ggproto(NULL, ggplot2::Scale),
-  guide = ggplot2::guide_none(),
-  position = NULL,
-  aesthetics = NULL,
-  name = ggplot2::waiver(),
-  scale_is_discrete = FALSE,
-  limits = NULL,
-  continuous_range = NULL,
-  breaks = NULL,
-  minor_breaks = NULL,
-  is_empty = function(self) {
-    is.null(self$get_breaks()) && is.null(self$get_breaks_minor())
-  },
-  is_discrete = function(self) self$scale_is_discrete,
-  dimension = function(self) self$continuous_range,
-  get_limits = function(self) self$limits,
-  get_breaks = function(self) self$breaks,
-  get_breaks_minor = function(self) self$minor_breaks,
-  get_labels = function(self, breaks = self$get_breaks()) {
-    self$scale$get_labels(breaks)
-  },
-  rescale = function(self, x) {
-    self$scale$rescale(x, self$limits, self$continuous_range)
-  },
-  map = function(self, x) {
-    if (self$is_discrete()) {
-      self$scale$map(x, self$limits)
+  view_scale_secondary <- function(scale, limits = scale$get_limits(),
+                                   continuous_range =
+                                     scale$dimension(limits = limits)) {
+    if (is.null(scale$secondary.axis) ||
+        inherits(scale$secondary.axis, "waiver") ||
+        scale$secondary.axis$empty()) {
+      # if there is no second axis, return the primary scale with no guide
+      # this guide can be overridden using guides()
+      primary_scale <- view_scale_primary(scale, limits, continuous_range)
+      scale_flip_position(primary_scale)
+      primary_scale$guide <- ggplot2::guide_none()
+      primary_scale
     } else {
-      self$scale$map(x, self$continuous_range)
-    }
-  },
-  make_title = function(self, title) {
-    self$scale$make_title(title)
-  },
-  break_positions = function(self) {
-    self$rescale(self$get_breaks())
-  },
-  break_positions_minor = function(self) {
-    b <- self$get_breaks_minor()
-    if (is.null(b)) {
-      return(NULL)
-    }
+      scale$secondary.axis$init(scale)
+      break_info <- scale$secondary.axis$break_info(continuous_range, scale)
+      names(break_info) <- gsub("sec\\.", "", names(break_info))
 
-    self$rescale(b)
+      # flip position from the original scale by default
+      # this can (should) be overridden in the guide
+      position <- switch(scale$position,
+                         top = "bottom",
+                         bottom = "top",
+                         left = "right",
+                         right = "left",
+                         scale$position
+      )
+
+      ggproto(NULL, ViewScale,
+              scale = scale,
+              guide = scale$secondary.axis$guide,
+              position = position,
+              break_info = break_info,
+              # as far as scales are concerned, this is a regular scale with
+              # different breaks and labels in a different data space
+              aesthetics = scale$aesthetics,
+              name = scale$sec_name(),
+              make_title = function(self, title) self$scale$make_sec_title(title),
+              limits = limits,
+              continuous_range = continuous_range,
+              dimension = function(self) self$break_info$range,
+              get_limits = function(self) self$break_info$range,
+              get_breaks = function(self) self$break_info$major_source,
+              get_breaks_minor = function(self) self$break_info$minor_source,
+              break_positions = function(self) self$break_info$major,
+              break_positions_minor = function(self) self$break_info$minor,
+              get_labels = function(self, breaks = self$get_breaks()) {
+                self$break_info$labels
+              },
+              rescale = function(x) rescale(x, from = break_info$range, to = c(0, 1))
+      )
+    }
   }
-)
+  ViewScale <- ggproto("ViewScale", NULL,
+    # map, rescale, and make_title need a reference
+    # to the original scale
+    scale = ggproto(NULL, ggplot2::Scale),
+    guide = ggplot2::guide_none(),
+    position = NULL,
+    aesthetics = NULL,
+    name = ggplot2::waiver(),
+    scale_is_discrete = FALSE,
+    limits = NULL,
+    continuous_range = NULL,
+    breaks = NULL,
+    minor_breaks = NULL,
+    is_empty = function(self) {
+      is.null(self$get_breaks()) && is.null(self$get_breaks_minor())
+    },
+    is_discrete = function(self) self$scale_is_discrete,
+    dimension = function(self) self$continuous_range,
+    get_limits = function(self) self$limits,
+    get_breaks = function(self) self$breaks,
+    get_breaks_minor = function(self) self$minor_breaks,
+    get_labels = function(self, breaks = self$get_breaks()) {
+      self$scale$get_labels(breaks)
+    },
+    rescale = function(self, x) {
+      self$scale$rescale(x, self$limits, self$continuous_range)
+    },
+    map = function(self, x) {
+      if (self$is_discrete()) {
+        self$scale$map(x, self$limits)
+      } else {
+        self$scale$map(x, self$continuous_range)
+      }
+    },
+    make_title = function(self, title) {
+      self$scale$make_title(title)
+    },
+    break_positions = function(self) {
+      self$rescale(self$get_breaks())
+    },
+    break_positions_minor = function(self) {
+      b <- self$get_breaks_minor()
+      if (is.null(b)) {
+        return(NULL)
+      }
+
+      self$rescale(b)
+    }
+  )
+} # nocov end
+
