@@ -1,5 +1,6 @@
 test_that("get_scale_data works", {
-  expect_named(get_scale_data("stages"), c("name", "max_age", "min_age", "abbr", "color"))
+  expect_named(get_scale_data("stages"),
+               c("name", "max_age", "min_age", "abbr", "color"))
   expect_equal(get_scale_data("stages"), deeptime::stages)
   expect_equal(get_scale_data("epochs"), deeptime::epochs)
   expect_equal(get_scale_data("periods"), deeptime::periods)
@@ -10,8 +11,10 @@ test_that("get_scale_data works", {
 
   expect_error(get_scale_data("e"))
   expect_error(get_scale_data("international house of pancakes"))
-  expect_named(get_scale_data("North American Land Mammal Ages"),
-               c("name", "max_age", "min_age", "abbr", "color"))
+  expect_named(
+    get_scale_data("North American Land Mammal Ages"),
+    c("name", "max_age", "min_age", "abbr", "color")
+  )
 })
 
 test_that("getScaleData is deprecated", {
